<?php
/**
 * Prasoon Theme Customizer
 *
 * @package Prasoon
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function prasoon_customize_register( $wp_customize ) {

    require( get_template_directory() . '/inc/customizer/custom-controls/control-custom-content.php' );

    $wp_customize->remove_section( 'themes' );
    $wp_customize->remove_section( 'background_image' );
    $wp_customize->remove_section( 'colors' );
    $wp_customize->remove_section( 'header_image' );
    



    $wp_customize->add_section(
        'prasoon_general_settings',
        array (
            'priority'      => 25,
            'capability'    => 'edit_theme_options',
            'theme_supports'=> '',
            'title'         => __( 'General Settings', 'prasoon' )
        )
    );    


    // Theme logo content page
    $wp_customize->add_setting(
        'theme_content_logo',
        array(
            'type' => 'theme_mod',
            'sanitize_callback' => 'prasoon_sanitize_image'
        )
    );

    $wp_customize->add_control(
      new WP_Customize_Image_Control(
          $wp_customize,
          'theme_content_logo',
          array(
              'settings'      => 'theme_content_logo',
              'section'       => 'prasoon_general_settings',
              'label'         => __( 'Logo Content Page', 'prasoon' ),
              'description'   => __( 'Upload logo for the content page of your website. Recommended height is 70px', 'prasoon' )
          )
      )
    );


    // Home Section Background
    $wp_customize->add_setting(
        'theme_home_bg',
        array(
            'type' => 'theme_mod',
            'sanitize_callback' => 'prasoon_sanitize_image'
        )
    );

    $wp_customize->add_control(
      new WP_Customize_Image_Control(
          $wp_customize,
          'theme_home_bg',
          array(
              'settings'      => 'theme_home_bg',
              'section'       => 'prasoon_general_settings',
              'label'         => __( 'Home Background Image', 'prasoon' ),
              'description'   => __( 'Upload background image for your home section', 'prasoon' )
          )
      )
    );

    // Home Section Promo Heading text
    $wp_customize->add_setting(
        'home_heading_text',
        array(
            'type' => 'theme_mod',
            'default'           => '',
            'sanitize_callback' => 'prasoon_sanitize_html'
        )
    );

    $wp_customize->add_control(
        'home_heading_text',
        array(
            'settings'      => 'home_heading_text',
            'section'       => 'prasoon_general_settings',
            'type'          => 'textbox',
            'label'         => __( 'Promo Heading Text', 'prasoon' ),
            'description'   => __( 'Promotional heading for the home section', 'prasoon' ),
        )
    );

    // Home Section Promo SubHeading text
    $wp_customize->add_setting(
        'home_subheading_text',
        array(
            'type' => 'theme_mod',
            'default'           => '',
            'sanitize_callback' => 'prasoon_sanitize_html'
        )
    );

    $wp_customize->add_control(
        'home_subheading_text',
        array(
            'settings'      => 'home_subheading_text',
            'section'       => 'prasoon_general_settings',
            'type'          => 'textarea',
            'label'         => __( 'Promo SubHeading Text', 'prasoon' ),
            'description'   => __( 'Promotional subheading for the home section', 'prasoon' ),
        )
    );


    // Home Section Button text
    $wp_customize->add_setting(
        'home_button_text',
        array(
            'type' => 'theme_mod',
            'default'           => '',
            'sanitize_callback' => 'prasoon_sanitize_html'
        )
    );

    $wp_customize->add_control(
        'home_button_text',
        array(
            'settings'      => 'home_button_text',
            'section'       => 'prasoon_general_settings',
            'type'          => 'textbox',
            'label'         => __( 'Button Text', 'prasoon' ),
            'description'   => __( 'Button text for the home section', 'prasoon' ),
        )
    );


    // Home Section Button url
    $wp_customize->add_setting(
        'home_button_url',
        array(
            'type' => 'theme_mod',
            'default'           => '',
            'sanitize_callback' => 'prasoon_sanitize_html'
        )
    );

    $wp_customize->add_control(
        'home_button_url',
        array(
            'settings'      => 'home_button_url',
            'section'       => 'prasoon_general_settings',
            'type'          => 'textbox',
            'label'         => __( 'Button URL', 'prasoon' ),
            'description'   => __( 'Button URL for the home section', 'prasoon' ),
        )
    );    


    // Copyright text
    $wp_customize->add_setting(
        'copyright_text',
        array(
            'type' => 'theme_mod',
            'default'           => sprintf( __( 'Copyright %s. All rights reserved.', 'prasoon' ), wp_filter_post_kses( get_bloginfo( 'name' ) ) ),
            'sanitize_callback' => 'prasoon_sanitize_html'
        )
    );

    $wp_customize->add_control(
        'copyright_text',
        array(
            'settings'      => 'copyright_text',
            'section'       => 'prasoon_general_settings',
            'type'          => 'textarea',
            'label'         => __( 'Footer copyright text', 'prasoon' ),
            'description'   => __( 'Copyright text to be displayed in the footer. HTML allowed.', 'prasoon' )
        )
    );



}
add_action( 'customize_register', 'prasoon_customize_register' );


/**
 * Sanitize text box.
 *
 * @param string $input
 * @return string
 */
function prasoon_sanitize_text( $input ) {
    return esc_html( $input );
}

/**
 * Sanitize checkbox.
 *
 * @param bool $checked Whether the checkbox is checked.
 * @return bool Whether the checkbox is checked.
 */
function prasoon_sanitize_checkbox( $checked ) {
    // Boolean check.
    return ( ( isset( $checked ) && true == $checked ) ? true : false );
}

/**
 * URL sanitization.
 *
 * @see esc_url_raw() https://developer.wordpress.org/reference/functions/esc_url_raw/
 *
 * @param string $url URL to sanitize.
 * @return string Sanitized URL.
 */
function prasoon_sanitize_url( $url ) {
    return esc_url_raw( $url );
}

/**
 * Select sanitization
 * @see sanitize_key()               https://developer.wordpress.org/reference/functions/sanitize_key/
 * @see $wp_customize->get_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/get_control/
 *
 * @param string               $input   Slug to sanitize.
 * @param WP_Customize_Setting $setting Setting instance.
 * @return string Sanitized slug if it is a valid choice; otherwise, the setting default.
 */
function prasoon_sanitize_select( $input, $setting ) {

    // Ensure input is a slug.
    $input = sanitize_key( $input );

    // Get list of choices from the control associated with the setting.
    $choices = $setting->manager->get_control( $setting->id )->choices;

    // If the input is a valid key, return it; otherwise, return the default.
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/**
 * Sanitize textarea.
 *
 * @param string $input
 * @return string
 */
function prasoon_sanitize_textarea( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}

/**
 * Sanitize image.
 *
 * @param string               $image   Image filename.
 * @param WP_Customize_Setting $setting Setting instance.
 * @return string The image filename if the extension is allowed; otherwise, the setting default.
 */
function prasoon_sanitize_image( $image, $setting ) {
    /*
     * Array of valid image file types.
     *
     * The array includes image mime types that are included in wp_get_mime_types()
     */
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon'
    );
    // Return an array with file extension and mime_type.
    $file = wp_check_filetype( $image, $mimes );
    // If $image has a valid mime_type, return it; otherwise, return the default.
    return ( $file['ext'] ? $image : $setting->default );
}


/**
 * Sanitize the Sidebar Position value.
 *
 * @param string $position.
 * @return string (left|right).
 */
function prasoon_sanitize_sidebar_position( $position ) {
    if ( ! in_array( $position, array( 'left', 'right' ) ) ) {
        $position = 'right';
    }
    return $position;
}


/**
 * HTML sanitization
 *
 * @see wp_filter_post_kses() https://developer.wordpress.org/reference/functions/wp_filter_post_kses/
 *
 * @param string $html HTML to sanitize.
 * @return string Sanitized HTML.
 */
function prasoon_sanitize_html( $html ) {
    return wp_filter_post_kses( $html );
}

/**
 * CSS sanitization.
 *
 * @see wp_strip_all_tags() https://developer.wordpress.org/reference/functions/wp_strip_all_tags/
 *
 * @param string $css CSS to sanitize.
 * @return string Sanitized CSS.
 */
function prasoon_sanitize_css( $css ) {
    return wp_strip_all_tags( $css );
}

/**
 * Enqueue the customizer stylesheet.
 */
function prasoon_enqueue_customizer_stylesheets() {
    wp_register_style( 'customizer-css', get_template_directory_uri() . '/inc/customizer/assets/customizer.css', NULL, NULL, 'all' );
    wp_enqueue_style( 'customizer-css' );
}

add_action( 'customize_controls_print_styles', 'prasoon_enqueue_customizer_stylesheets' );
