<?php
/**
 * About section widget.
 */

 
class Prasoon_About_Section_Widget extends WP_Widget {
	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'pr_about_widget', // Base ID
			__( 'Prasoon: About Section', 'prasoon' ), // Name
			array( 'description' => __( 'Adds about section. Please use this widget only for "Business Template" widget area.', 'prasoon' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		extract( $args );

    $heading    = ! empty( $instance['heading'] ) ? $instance['heading'] : '';
    $subheading = ! empty( $instance['subheading'] ) ? $instance['subheading'] : '';
		$content = ! empty( $instance['content'] ) ? $instance['content'] : '';
		$buttontext = ! empty( $instance['buttontext'] ) ? $instance['buttontext'] : '';
    $image =  ! empty( $instance['image'] ) ? $instance['image'] : ''; 
    $image_desc = ! empty( $instance['image_desc'] ) ? $instance['image_desc'] : ''; 

		?>
			<section id="about">
				<div class="section-inner wow fadeInUp" data-wow-duration="4s" data-wow-delay="1s">
          <div class="container">
            <div class="about-section">
              <div class="row">
                <div class="title">
                  <div class="col-md-12">
                    <h3><?php echo $heading; ?></h3>
                    <p><?php echo $subheading; ?></p>
                  </div>
                </div>
              </div>
              <div class="row">
                <div class="content">
                  <div class="col-md-5 col-sm-12 col-xs-12">
                    <p><?php echo $content; ?></p>
                    <?php if($buttontext!=""):
                    ?><button type="button" class="btn btn-default black"><?php echo $buttontext; ?> <i class="fa fa-angle-double-right"></i></button><?php endif ?>
                  </div>
                  <div class="col-md-7 col-sm-12 col-xs-12">
                    <img class="img-responsive" src="<?php echo esc_url($image); ?>" alt="image">
                    <?php if($image_desc!=""):
                    ?><p class="img-descr"><?php echo $image_desc; ?></p><?php endif ?>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
			</section>
		<?php

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$heading    = ! empty( $instance['heading'] ) ? $instance['heading'] : '';
    $subheading = ! empty( $instance['subheading'] ) ? $instance['subheading'] : '';
    $content = ! empty( $instance['content'] ) ? $instance['content'] : '';
    $buttontext = ! empty( $instance['buttontext'] ) ? $instance['buttontext'] : '';
    $image =  ! empty( $instance['image'] ) ? $instance['image'] : ''; 
    $image_desc = ! empty( $instance['image_desc'] ) ? $instance['image_desc'] : ''; 
    ?>

    <p>
        <label for="<?php echo $this->get_field_id('heading'); ?>"><?php _e('Heading:','prasoon'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('heading'); ?>" name="<?php echo $this->get_field_name('heading'); ?>" type="text" value="<?php echo $heading; ?>" />
    </p>
		<p>
        <label for="<?php echo $this->get_field_id('subheading'); ?>"><?php _e('Sub heading:','prasoon'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('subheading'); ?>" name="<?php echo $this->get_field_name('subheading'); ?>" type="text" value="<?php echo $subheading; ?>" />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('content'); ?>"><?php _e('About Content','prasoon'); ?></label>
        <textarea class="widefat" rows="16" cols="20" id="<?php echo $this->get_field_id('content'); ?>" name="<?php echo $this->get_field_name('content'); ?>"><?php echo $content; ?></textarea>
    </p>
		<p>
        <label for="<?php echo $this->get_field_id('buttontext'); ?>"><?php _e('Button Text:','prasoon'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('buttontext'); ?>" name="<?php echo $this->get_field_name('buttontext'); ?>" type="text" value="<?php echo $buttontext; ?>" />
    </p>

    <p>
        <label for="<?php echo $this->get_field_name( 'image' ); ?>"><?php _e( 'Image Url(Recommended width: 600px):','prasoon'); ?></label>
        <input name="<?php echo $this->get_field_name( 'image' ); ?>" id="<?php echo $this->get_field_id( 'image' ); ?>" class="widefat" type="text" size="36"  value="<?php echo esc_url( $image ); ?>" />        
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('image_desc'); ?>"><?php _e('Image Description','prasoon'); ?></label>
        <textarea class="widefat" rows="5" cols="8" id="<?php echo $this->get_field_id('image_desc'); ?>" name="<?php echo $this->get_field_name('image_desc'); ?>"><?php echo $image_desc; ?></textarea>
    </p>
    <?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

    $instance['heading'] = wp_filter_post_kses($new_instance['heading']);
    $instance['subheading'] = wp_filter_post_kses($new_instance['subheading']);
		$instance['content'] = wp_filter_post_kses($new_instance['content']);
    $instance['buttontext'] = wp_filter_post_kses($new_instance['buttontext']);
    $instance['image']  = strip_tags( $new_instance['image'] );
    $instance['image_desc']   = wp_filter_post_kses($new_instance['image_desc']);

    return $instance;
	}

}

// register widget
function register_prasoon_about_section_widget() {
    register_widget( 'Prasoon_About_Section_Widget' );
}
add_action( 'widgets_init', 'register_prasoon_about_section_widget' );
