<?php
/**
 * Blog Section widget.
 */

 /**
  * Load scripts.
  */


class Prasoon_Blog_Section_Widget extends WP_Widget {
	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'pr_blog_widget', // Base ID
			__( 'Prasoon: Blog Section', 'prasoon' ), // Name
			array( 'description' => __( 'Adds Blog section. Please use this widget only for "Business Template" widget area.', 'prasoon' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		extract( $args );

    $heading    = ! empty( $instance['heading'] ) ? $instance['heading'] : '';
    $subheading = ! empty( $instance['subheading'] ) ? $instance['subheading'] : '';

  		$options = array(
        'post_type' => 'post',
        'posts_per_page' => 3,
    );
    $query = new WP_Query( $options );
    // run the loop based on the query
    if ( $query->have_posts() ) { ?>
      <section id="blog">
        <div class="section-inner wow fadeInUp" data-wow-duration="4s">
          <div class="container">
            <div class="blog-section">
              <div class="row">
                <div class="title">
                  <div class="col-md-12">
                    <h3><?php echo $heading; ?></h3>
                    <p><?php echo $subheading; ?></p>
                  </div>
                </div>
              </div>
              <div class="row">
                <div class="content">
      					<?php
									while ( $query->have_posts() ) {
									  $query->the_post();
										$postid = get_the_ID();
								?>
                    <div class="col-md-4">
                      <div class="blog-wrap">
                        <div class="image">
                          <?php if ( has_post_thumbnail()) {
                            the_post_thumbnail('small');
                          }
                          else { ?>
                          <img src="<?php echo get_template_directory_uri().'/img/blog-bg.jpg' ?>" alt="" /> <?php
                          }
                          ?>
                          <div class="datetime">
                            <div class="datetime-section">
                              <h3><?php the_time('j M'); ?></h3>
                              <h4><?php the_time('Y'); ?></h4>
                            </div>
                          </div>
                        </div>
                        <div class="heading">
                          <h2><a href="<?php the_permalink() ?>"><?php the_title(); ?></a></h2>
                        </div>
                        <div class="excerpt">
                          <span class="postedby"><i class="fa fa-user"></i><?php the_author() ?></span>
                          <span class="comments"><i class="fa fa-comments"></i><?php comments_number('0','1','%'); ?>  Comments</span>                          
                        </div>
                        <div class="blog-content">
                          <p><?php the_excerpt(); ?></p>
                          <a class="read-more" href="<?php the_permalink() ?>">READ MORE <i class="fa fa-plus-circle"></i></a>
                        </div>
                      </div>
                    </div>
										<?php
										}?>
                  </div>
              	</div>
          		</div>
            </div>
          </div>
        </section>

       <?php
      }

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
    $heading    = ! empty( $instance['heading'] ) ? $instance['heading'] : '';
    $subheading = ! empty( $instance['subheading'] ) ? $instance['subheading'] : '';
    ?>

    <p>
        <label for="<?php echo $this->get_field_id('heading'); ?>"><?php _e('Heading:','prasoon'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('heading'); ?>" name="<?php echo $this->get_field_name('heading'); ?>" type="text" value="<?php echo $heading; ?>" />
    </p>
		<p>
        <label for="<?php echo $this->get_field_id('subheading'); ?>"><?php _e('Sub heading:','prasoon'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('subheading'); ?>" name="<?php echo $this->get_field_name('subheading'); ?>" type="text" value="<?php echo $subheading; ?>" />
    </p>
    <?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

    $instance['heading'] = wp_filter_post_kses($new_instance['heading']);
    $instance['subheading'] = wp_filter_post_kses($new_instance['subheading']);

    return $instance;
	}

}

// register widget
function register_prasoon_blog_section_widget() {
    register_widget( 'Prasoon_Blog_Section_Widget' );
}
add_action( 'widgets_init', 'register_prasoon_blog_section_widget' );
