<?php
/**
 * Services section widget.
 */

class Prasoon_Services_Section_Widget extends WP_Widget {
	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'pr_services_widget', // Base ID
			__( 'Prasoon: Services Section', 'prasoon' ), // Name
			array( 'description' => __( 'Adds Services section. Please use this widget only for "Business Template" widget area.', 'prasoon' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		extract( $args );

    $heading    = ! empty( $instance['heading'] ) ? $instance['heading'] : '';
    $subheading = ! empty( $instance['subheading'] ) ? $instance['subheading'] : '';

		?>
    <section id="services">
      <div class="section-inner wow fadeInUp" data-wow-duration="4s">
        <div class="container">
          <div class="services-section">
            <div class="row">
              <div class="title">
                <div class="col-md-12">
                  <h3><?php echo $heading; ?></h3>
                  <p><?php echo $subheading; ?></p>
                </div>
              </div>
            </div>
            <div class="row">
              <div class="content">
              <?php
              for( $i=1; $i<4; $i++ ) { 

                $font_icon    = ! empty( $instance['font_icon'.$i] ) ? $instance['font_icon'.$i] : '';
                $title    = ! empty( $instance['title'.$i] ) ? $instance['title'.$i] : '';
                $content    = ! empty( $instance['content'.$i] ) ? $instance['content'.$i] : '';
                $button_url    = ! empty( $instance['button_url'.$i] ) ? $instance['button_url'.$i] : '';

                ?>
                <div class="col-md-4">
                  <div class="services">
                    <div class="icon-service">
                      <i class="fa <?php echo $font_icon; ?>"></i>
                    </div>
                    <div class="heading">
                      <h4><?php echo $title; ?></h4>
                    </div>
                    <div class="descr">
                      <p><?php echo $content; ?></p>
                    </div>

                    <?php if(""!=$button_url){
                      ?>
                          <div class="read-more">
                            <a href="<?php echo $button_url; ?>"><button type="button" class="btn btn-default black">READ MORE </button></a>
                          </div>
                      <?php
                    }
                    ?>
                  </div>
                </div> <?php
              } ?>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
		<?php

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$heading    = ! empty( $instance['heading'] ) ? $instance['heading'] : '';
    $subheading = ! empty( $instance['subheading'] ) ? $instance['subheading'] : '';
    ?>

    <p>
        <label for="<?php echo $this->get_field_id('heading'); ?>"><?php _e('Heading:','prasoon'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('heading'); ?>" name="<?php echo $this->get_field_name('heading'); ?>" type="text" value="<?php echo $heading; ?>" />
    </p>
		<p>
        <label for="<?php echo $this->get_field_id('subheading'); ?>"><?php _e('Sub heading:','prasoon'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('subheading'); ?>" name="<?php echo $this->get_field_name('subheading'); ?>" type="text" value="<?php echo $subheading; ?>" />
    </p>

    <div class="services-block">
			<?php for( $i = 1; $i < 4; $i++ ) { ?>
				<div class="services-block-box">
					<div class="services-block-head"><a href="#">Block <?php echo $i ?></a><span class="service-plus">+</span><span class="service-minus">-</span></div>
					<div class="services-block-content">
						<?php $font_icon = ! empty( $instance['font_icon'.$i] ) ? $instance['font_icon'.$i] : ''; ?>
            <?php $title = ! empty( $instance['title'.$i] ) ? $instance['title'.$i] : ''; ?>
            <?php $content = ! empty( $instance['content'.$i] ) ? $instance['content'.$i] : ''; ?>
            <?php $button_url = ! empty( $instance['button_url'.$i] ) ? $instance['button_url'.$i] : ''; ?>
						<p>
							<label for="<?php echo $this->get_field_id( 'font_icon'.$i ); ?>"><?php _e( 'Font-Awesome Icon (for eg: fa-mobile)', 'prasoon' ); ?>:</label>
							<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'font_icon'.$i ); ?>" name="<?php echo $this->get_field_name( 'font_icon'.$i ); ?>" value="<?php echo esc_attr( $font_icon ); ?>" />
						</p>
            <p>
              <label for="<?php echo $this->get_field_id( 'title'.$i ); ?>"><?php _e( 'Title', 'prasoon' ); ?>:</label>
              <input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title'.$i ); ?>" name="<?php echo $this->get_field_name( 'title'.$i ); ?>" value="<?php echo esc_attr( $title ); ?>" />
						</p>
            <p>
              <label for="<?php echo $this->get_field_id( 'content'.$i ); ?>"><?php _e( 'Content', 'prasoon' ); ?>:</label>
              <textarea class="widefat" rows="16" cols="20" id="<?php echo $this->get_field_id('content'.$i); ?>" name="<?php echo $this->get_field_name('content'.$i); ?>"><?php echo $content; ?></textarea>
						</p>
            <p>
              <label for="<?php echo $this->get_field_id( 'button_url'.$i ); ?>"><?php _e( 'Button Url', 'prasoon' ); ?>:</label>
              <input type="text" class="widefat" id="<?php echo $this->get_field_id( 'button_url'.$i ); ?>" name="<?php echo $this->get_field_name( 'button_url'.$i ); ?>" value="<?php echo esc_url( $button_url ); ?>" />
						</p>
					</div>
				</div>
			<?php } ?>
		</div>
    <?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
    $instance[ 'heading'] = wp_filter_post_kses( $new_instance['heading'] );
    $instance[ 'subheading'] = wp_filter_post_kses( $new_instance['subheading'] );

    for( $i=1; $i<4; $i++ ) {
			$instance[ 'font_icon'.$i ] = strip_tags( $new_instance[ 'font_icon'.$i ] );
			$instance[ 'title'.$i ] = wp_filter_post_kses($new_instance['title'.$i]);
      $instance[ 'content'.$i ] = wp_filter_post_kses($new_instance['content'.$i]);
      $instance[ 'button_url'.$i ] = esc_url($new_instance['button_url'.$i]);
		}

    return $instance;
	}

}

// register widget
function register_prasoon_services_section_widget() {
    register_widget( 'Prasoon_Services_Section_Widget' );
}
add_action( 'widgets_init', 'register_prasoon_services_section_widget' );
